flow.vat <- stats::ts(c(
16.1,
19.2,
14.5,
11,
13.6,
12.5,
10.5,
10.1,
9.68,
9.02,
8.8,
8.58,
8.14,
7.5,
7.92,
7.92,
7.71,
7.1,
6.7,
3.98,
5.16,
6.1,
6.9,
6.9,
7.1,
7.3,
7.3,
5.71,
6.9,
8.14,
7.5,
7.1,
6.9,
6.7,
6.7,
6.9,
6.9,
6.7,
6.5,
6.5,
6.7,
6.9,
7.1,
6.7,
6.7,
6.7,
6.9,
5.34,
5.34,
5.9,
6.3,
6.9,
7.92,
21,
14.2,
11.6,
10.1,
9.24,
8.58,
8.14,
7.92,
7.71,
7.71,
7.5,
7.1,
6.9,
6.9,
6.9,
6.5,
7.71,
4.65,
3.98,
5.16,
6.1,
6.1,
8.14,
13.6,
9.68,
8.36,
9.24,
8.58,
8.36,
7.92,
9.02,
9.02,
8.15,
7.92,
7.5,
7.3,
6.9,
6.9,
7.5,
6.7,
6.7,
6.9,
6.7,
6.5,
6.3,
6.3,
6.3,
6.3,
6.1,
5.9,
6.5,
6.3,
6.1,
7.1,
8.14,
9.9,
14.2,
16.5,
19.2,
23.5,
25.2,
35.9,
31.5,
19.2,
16.9,
13.6,
11,
10.1,
9.9,
10.1,
10.3,
13,
20.1,
24.1,
36.7,
32.9,
28.7,
31.5,
33.7,
30.8,
26.3,
21.5,
17.3,
19.2,
16.9,
16.1,
15.6,
18,
19.7,
17.7,
16.9,
19.7,
16.9,
14.8,
11.3,
11.3,
10.1,
10.1,
9.9,
9.24,
9.02,
9.46,
10.1,
9.9,
10.8,
9.68,
9.24,
9.02,
8.8,
8.8,
8.58,
8.58,
9.9,
9.9,
11.3,
9.9,
9.24,
9.24,
9.02,
8.36,
8.14,
8.36,
10.1,
11.6,
9.9,
9.9,
9.68,
9.46,
9.02,
8.36,
8.36,
10.5,
10.5,
10.1,
10.1,
9.68,
9.9,
11,
10.5,
9.46,
9.02,
9.24,
9.9,
9.24,
9.46,
8.8,
8.8,
9.46,
9.46,
9.02,
8.8,
8.58,
8.36,
8.36,
8.36,
8.58,
8.36,
7.92,
7.92,
7.92,
7.71,
7.5,
7.5,
7.3,
7.5,
7.71,
7.5,
7.3,
7.3,
7.1,
7.1,
7.1,
7.5,
7.3,
7.5,
7.1,
7.3,
7.3,
7.71,
8.14,
7.5,
7.71,
7.71,
7.71,
7.71,
8.14,
9.02,
9.02,
9.02,
9.24,
8.58,
9.02,
8.58,
7.5,
8.8,
9.46,
8.14,
7.92,
7.5,
7.5,
7.3,
7.3,
7.5,
7.5,
7.5,
7.3,
7.1,
7.1,
6.9,
7.1,
7.3,
7.1,
7.3,
7.71,
7.3,
7.3,
7.1,
6.9,
6.9,
6.7,
7.3,
7.1,
7.1,
6.5,
5.71,
6.7,
8.58,
7.3,
6.7,
6.3,
6.1,
7.92,
10.1,
9.24,
7.71,
8.8,
10.1,
8.58,
9.02,
8.36,
8.14,
7.71,
7.1,
7.1,
7.71,
7.5,
7.5,
5.34,
5.34,
8.58,
8.36,
8.58,
7.5,
7.1,
5.9,
6.9,
6.9,
7.5,
7.71,
7.5,
7.3,
5.71,
4.82,
4.48,
5.16,
6.1,
7.1,
7.5,
7.5,
7.71,
7.92,
7.1,
7.3,
7.3,
8.14,
8.36,
8.36,
8.14,
7.71,
7.1,
6.9,
6.9,
7.1,
6.7,
6.5,
6.7,
7.1,
7.3,
7.1,
6.9,
7.1,
7.5,
7.1,
7.5,
7.3,
7.1,
6.9,
6.7,
6.7,
7.92,
11.6,
10.8,
6.7,
5.34,
6.1,
7.5,
7.92,
7.92,
7.71,
7.5,
7.5,
7.3,
7.1,
6.9,
6.7,
6.7,
6.3,
9.02,
16.5,
21.5,
15.6,
16.9,
23,
20.1,
14.5,
12.5,
11.6,
11,
10.8,
9.68,
9.02,
10.3,
10.1,
9.9,
9.46,
8.8,
8.58,
8.36,
7.71,
7.3,
7.3,
7.5,
8.14,
8.36,
6.36,
5.16,
6.9,
7.71,
7.71,
7.71,
7.71,
7.5,
7.5,
7.5,
7.5,
6.7,
6.3,
6.7,
7.71,
7.71,
6.9,
6.7,
6.7,
7.92,
8.36,
8.36,
8.14,
8.36,
9.02,
9.46,
9.68,
9.68,
9.68,
9.46,
9.24,
8.8,
8.58,
8.36,
8.36,
8.14,
8.14,
8.14,
8.58,
8.58,
8.14,
8.36,
8.8,
9.46,
9.9,
11.6,
14.5,
17.3,
19.2,
18.4,
14.5,
12.2,
10.8,
8.58,
8.36,
8.58,
7.5,
7.1,
7.3,
7.71,
8.14,
8.14,
7.1,
7.5,
7.1,
7.1,
7.3,
7.71,
8.8,
9.9,
14.2,
18.8,
25.2,
31.5,
22,
24.1,
39.2,
50.1,
46.2,
35.2,
30.8,
31.5,
31.5,
25.2,
21.5,
17.3,
12.7,
13.3,
13,
12.5,
11.6,
11.9,
13,
13,
12.5,
11.6,
11.6,
10.8,
10.1,
10.1,
9.68,
9.46,
10.3,
11.6,
13.9,
13.9,
12.5,
11.9,
12.2,
13,
13.3,
13,
12.7,
11.9,
13.3,
12.5,
11.9,
11.6,
10.5,
10.1,
9.9,
9.68,
9.68,
9.9,
10.8,
11,
10.8,
10.8,
10.1,
9.46,
9.24,
9.02,
8.8,
8.58,
9.24,
10.8,
11.9,
12.7,
11.9,
11.3,
11.6,
12.2,
12.7,
11.9,
11.6,
11.3,
11.3,
11.3,
11.3,
11.3,
11,
10.8,
10.3,
10.1,
9.9,
9.9,
9.9,
9.9,
9.68,
9.46,
9.24,
9.02,
9.02,
8.8,
8.58,
8.58,
8.14,
8.14,
8.14,
8.14,
8.14,
8.14,
8.14,
8.14,
8.14,
7.92,
7.71,
7.5,
7.71,
7.71,
7.71,
7.5,
7.71,
7.92,
7.71,
8.8,
9.9,
8.58,
8.14,
7.92,
7.92,
7.92,
7.92,
8.36,
7.71,
7.92,
7.92,
7.71,
7.5,
7.3,
7.3,
7.3,
7.3,
7.3,
7.3,
7.5,
7.71,
7.92,
7.5,
7.5,
7.5,
7.5,
7.71,
7.5,
7.3,
7.3,
7.3,
7.92,
7.3,
7.3,
7.1,
7.1,
7.1,
6.9,
6.9,
6.9,
6.9,
6.9,
6.9,
7.1,
7.1,
7.1,
6.9,
6.9,
7.71,
8.14,
8.36,
8.8,
7.92,
7.71,
7.5,
7.3,
8.36,
8.36,
8.58,
7.71,
7.92,
7.92,
8.58,
9.9,
7.92,
7.92,
7.71,
7.71,
7.71,
6.9,
6.3,
6.9,
6.1,
6.1,
6.5,
7.3,
6.9,
7.92,
8.8,
8.14,
6.7,
7.1,
6.7,
6.7,
10.8,
13.6,
11.3,
8.58,
8.58,
7.71,
6.3,
5.71,
7.92,
11.3,
9.68,
8.14,
7.3,
6.9,
5.34,
6.7,
6.7,
6.7,
6.3,
7.5,
8.36,
8.36,
8.58,
8.58,
9.46,
9.68,
8.8,
8.14,
7.5,
6.9,
6.9,
6.7,
6.7,
6.7,
9.02,
9.24,
8.58,
7.71,
7.3,
7.71,
7.92,
8.14,
7.92,
7.71,
7.5,
6.5,
7.71,
8.14,
8.14,
9.02,
8.14,
7.1,
6.5,
6.1,
5.9,
5.71,
5.52,
5.52,
5.16,
4.82,
4.65,
4.65,
4.65,
4.65,
4.65,
4.65,
4.65,
4.48,
5.16,
5.52,
5.34,
5.34,
4.82,
4.65,
4.48,
4.31,
4.31,
4.31,
4.14,
3.82,
3.98,
3.98,
4.31,
5.71,
6.5,
6.3,
5.71,
5.71,
5.16,
4.65,
4.14,
3.98,
4.48,
4.48,
4.31,
4.65,
4.31,
3.98,
3.98,
3.98,
3.98,
3.98,
3.98,
3.82,
3.67,
3.67,
3.98,
3.98,
3.82,
3.82,
3.82,
4.14,
5.9,
4.48,
3.98,
3.98,
3.82,
3.67,
3.67,
3.67,
4.65,
3.98,
4.31,
4.31,
3.67,
4.31,
6.1,
7.3,
7.5,
7.5,
8.14,
10.8,
16.1,
14.8,
12.5,
9.9,
8.14,
6.9,
6.1,
5.34,
5.16,
4.99,
4.99,
4.99,
4.99,
5.52,
6.3,
7.3,
6.9,
5.9,
5.71,
5.71,
8.58,
31.5,
33.7,
18.4,
11.3,
16.1,
32.9,
45.3,
54,
25.7,
18,
15.9,
15.6,
14.5,
15.9,
35.9,
37.5,
29.4,
27.5,
30.1,
27.5,
30.8,
29.4,
22,
20.1,
35.9,
36.7,
32.9,
22,
18,
15.9,
15.2,
14.8,
13,
12.7,
12.5,
11,
9.68,
8.8,
7.92,
7.3,
6.9,
7.3,
10.3,
11,
11.3,
11.9,
12.5,
13.6,
12.2,
10.8,
9.9,
9.46,
8.8,
7.5,
7.1,
7.71,
7.1,
6.1,
5.34,
5.34,
5.34,
5.52,
5.52,
6.3,
6.7,
6.5,
5.9,
5.71,
5.9,
5.71,
5.52,
7.3,
7.5,
7.1,
7.3,
6.7,
6.9,
7.3,
7.5,
10.8,
11.6,
8.58,
7.92,
7.1,
6.7,
6.5,
6.1,
5.9,
5.9,
5.71,
5.52,
5.52,
5.52,
5.9,
5.9,
5.71,
5.52,
5.52,
5.34,
5.34,
5.52,
6.5,
6.5,
5.71,
5.34,
5.16,
4.99,
4.82,
4.82,
4.99,
4.82,
4.82,
4.82,
4.82,
4.82,
4.65,
4.48,
4.48,
4.31,
4.31,
4.14,
4.14,
4.31,
4.48,
4.31,
4.31,
4.31,
4.99,
5.71,
6.3,
6.1,
6.1,
5.9,
5.71,
5.52,
5.52,
5.52,
5.52,
5.52,
5.34,
5.34,
5.52,
5.52,
5.52,
5.34,
5.34,
5.52,
5.34,
5.52,
5.52,
5.34,
5.34,
5.34,
5.34,
5.71,
5.9,
6.3,
6.9,
7.5,
6.5,
6.1,
6.1,
5.9,
6.1,
6.1,
5.9,
6.5,
6.5,
6.1,
5.9,
5.9,
5.71,
5.9,
5.9,
5.71,
4.99,
4.65,
5.16,
5.34,
5.34,
4.65,
4.99,
5.71,
5.34,
5.34,
5.34,
5.34,
4.99,
5.34,
5.34,
5.34,
5.34,
5.52,
5.34,
5.52,
5.71,
6.5,
7.71,
6.9,
6.5,
6.7,
6.1,
5.9,
6.1,
5.9,
5.71,
7.92,
7.71,
7.1,
7.92,
5.34,
5.16,
8.14,
10.1,
7.92,
7.3,
6.9,
6.9,
6.9,
8.58,
7.3,
6.9,
7.3,
6.3,
5.16,
6.1,
5.52,
4.99,
5.34,
5.34,
5.34,
5.16,
5.71,
5.52,
5.52,
5.16,
4.82,
5.52,
6.1,
5.9,
5.71,
5.52,
5.16,
4.99,
4.48,
4.82,
5.16,
5.16,
5.16,
5.16,
5.16,
4.82,
4.65,
3.82,
4.14,
4.65,
4.65,
4.31,
4.31,
5.16,
5.16,
5.16,
5.16,
5.16,
4.99,
4.65,
5.16,
5.16,
5.16,
5.16,
5.16,
5.16,
5.16,
5.16,
5.34,
5.34),
start=c(1972,1),frequency=365)
flow.jok <- stats::ts(c(
30.2,
29,
28.4,
27.8,
27.8,
27.8,
27.8,
27.8,
27.8,
27.3,
27.3,
27.3,
26.2,
25.2,
26.7,
26.7,
26.7,
26.7,
26.7,
25.2,
25.7,
26.2,
26.2,
26.2,
26.2,
25.7,
26.2,
26.7,
28.4,
29,
27.8,
27.3,
26.7,
26.2,
25.7,
26.2,
26.2,
25.7,
25.7,
25.7,
25.7,
25.7,
25.7,
25.7,
25.2,
25.2,
25.2,
24.6,
25.2,
25.7,
26.7,
26.2,
25.7,
26.7,
26.7,
26.7,
26.2,
25.7,
25.7,
25.2,
25.2,
25.2,
24.6,
24.6,
24.6,
24.6,
24.6,
24.6,
23.6,
24.1,
24.1,
24.6,
24.1,
24.6,
24.6,
25.7,
28.4,
31.4,
30.2,
29,
28.4,
27.8,
26.7,
26.7,
27.8,
26.7,
26.2,
25.2,
25.2,
25.2,
24.6,
25.2,
25.2,
24.1,
24.1,
24.6,
24.1,
24.1,
24.1,
24.1,
23.6,
23.6,
23.6,
23.6,
23.6,
23.6,
23.6,
24.1,
24.1,
24.1,
25.2,
25.2,
26.7,
30.2,
41.7,
51.7,
44,
41,
35.7,
30.8,
27.8,
29,
29,
28.4,
27.8,
34.4,
47,
59.1,
101,
103,
90,
113,
121,
104,
94.8,
77.4,
83,
81.6,
80.2,
81.6,
90,
103,
111,
109,
103,
99.6,
91.6,
66.6,
59.1,
52.5,
51.7,
53.3,
52.5,
52.5,
58.3,
64.3,
67.8,
78.8,
66.6,
55.7,
57.4,
63.4,
67.8,
69,
70.2,
84.4,
90,
78.8,
60,
48.5,
42.4,
41.7,
40.2,
45.4,
50.9,
54.1,
50.1,
50.9,
52.5,
54.9,
59.1,
61.7,
63.4,
63.4,
65.5,
58.3,
58.3,
60.9,
66.6,
74.8,
73.7,
70.2,
65.5,
61.7,
61.7,
67.8,
60,
62.6,
61.7,
61.7,
63.4,
60.9,
60,
58.3,
54.9,
53.3,
63.4,
64.3,
77.4,
85.8,
67.8,
57.4,
54.1,
52.5,
51.7,
46.2,
43.2,
41,
39.6,
37,
36.4,
35.7,
35.7,
36.4,
38.9,
53.3,
58.3,
57.4,
50.1,
45.4,
41,
41,
40.2,
37.6,
46.2,
45.4,
45.4,
39.6,
40.2,
46.2,
47.7,
59.1,
58.3,
48.5,
56.6,
56.6,
44.7,
50.9,
58.3,
44.7,
38.9,
36.4,
34.4,
34.4,
34.4,
34.4,
34.4,
41.7,
47.7,
44,
38.3,
39.6,
37,
37.6,
38.9,
36.4,
37.6,
44,
41,
38.9,
39.6,
38.9,
37,
35.7,
34.4,
32,
33.2,
32,
34.4,
41.7,
36.4,
33.8,
32.6,
32,
29,
35.7,
38.9,
33.2,
32,
35.7,
33.8,
34.4,
32.6,
30.8,
30.8,
28.4,
28.4,
27.8,
27.8,
27.8,
25.7,
22,
28.4,
30.2,
29.6,
29,
28.4,
26.7,
27.3,
27.3,
27.3,
27.8,
26.7,
26.7,
26.7,
26.7,
26.2,
26.2,
26.2,
26.2,
26.2,
26.2,
26.7,
27.8,
27.8,
27.8,
27.8,
27.8,
27.8,
27.8,
27.8,
27.8,
27.8,
27.8,
27.8,
27.8,
27.8,
27.8,
27.8,
27.8,
27.8,
27.8,
27.8,
26.7,
26.7,
26.7,
26.7,
26.7,
26.7,
26.7,
26.7,
26.7,
29.6,
34.4,
34.4,
28.4,
28.4,
27.8,
29,
29.6,
30.8,
30.2,
29.6,
29.6,
29.6,
27.8,
28.4,
27.3,
27.8,
27.3,
30.2,
34.4,
38.3,
38.3,
45.4,
70.2,
59.1,
41.7,
37.6,
35.1,
34.4,
33.8,
31.4,
31.4,
31.4,
30.8,
30.2,
29.6,
29.6,
29,
28.4,
27.3,
27.3,
29,
28.4,
27.8,
27.3,
27.8,
25.2,
27.8,
27.3,
27.3,
27.3,
27.3,
25.7,
25.7,
25.7,
26.2,
25.2,
25.7,
25.7,
25.7,
26.7,
26.7,
25.7,
25.7,
26.2,
26.2,
25.7,
25.7,
24.6,
25.7,
25.7,
25.7,
25.2,
25.2,
25.2,
24.6,
25.2,
24.6,
24.6,
25.2,
25.7,
24.6,
24.6,
26.7,
26.7,
26.2,
26.2,
26.7,
27.3,
27.3,
28.4,
29.6,
29,
29.6,
30.8,
29.6,
27.3,
27.3,
26.2,
25.2,
25.7,
25.2,
23.6,
24.6,
24.6,
24.1,
24.1,
24.1,
24.1,
24.1,
24.1,
24.1,
24.1,
25.2,
24.6,
26.2,
27.8,
32,
38.3,
36.4,
35.7,
44.7,
58.3,
67.8,
64.3,
64.3,
60,
60.9,
55.7,
49.3,
41.7,
35.1,
33.2,
32.6,
30.8,
30.2,
29.6,
29.6,
29.6,
29.6,
32,
30.2,
29.6,
27.3,
28.4,
27.8,
26.2,
27.3,
27.8,
40.2,
60.9,
56.6,
46.2,
45.4,
47.7,
51.7,
53.3,
50.9,
51.7,
59.1,
55.7,
53.3,
51.7,
50.9,
38.9,
37.6,
37.6,
38.3,
42.4,
47.7,
47,
48.5,
49.3,
47.7,
41.7,
38.9,
37,
35.1,
34.4,
36.4,
49.3,
65.5,
87.2,
109,
113,
98,
109,
127,
125,
115,
115,
91.6,
87.2,
85.8,
71.3,
70.2,
63.4,
61.7,
61.7,
60.9,
60.9,
63.4,
62.6,
66.6,
76,
90,
116,
111,
132,
123,
113,
98,
87.2,
78.8,
69,
63.4,
61.7,
62.6,
62.6,
64.3,
76,
84.4,
84.4,
84.4,
66.6,
54.9,
52.5,
52.5,
55.7,
55.7,
59.1,
64.3,
47.7,
44,
41.7,
41.7,
43.2,
41.7,
47.7,
52.5,
54.9,
57.4,
54.9,
45.4,
41.7,
40.2,
40.2,
38.9,
39.6,
46.2,
64.3,
67.8,
63.4,
61.7,
65.5,
57.4,
55.7,
53.3,
49.3,
47,
43.2,
42.4,
41,
39.6,
39.6,
36.4,
35.7,
37.6,
44,
55.7,
70.2,
63.4,
53.3,
50.9,
52.5,
51.7,
47.7,
41.7,
38.3,
37,
40.2,
49.3,
44.7,
38.3,
35.1,
35.1,
35.1,
50.9,
60.9,
60,
42.4,
44,
43.2,
42.4,
35.1,
33.8,
33.8,
33.8,
33.2,
32.6,
39.8,
30.2,
29,
29,
29,
30.2,
31.4,
30.2,
32.6,
32.6,
33.2,
30.2,
29,
28.4,
30.8,
35.1,
41.7,
60.9,
40.2,
35.7,
33.8,
30.2,
29.6,
31.4,
35.1,
35.1,
32,
31.4,
30.2,
27.8,
29,
29,
27.3,
26.2,
27.3,
28.4,
28.4,
28.4,
28.4,
28.4,
28.4,
27.8,
27.8,
28.4,
29,
29,
29,
28.4,
29.6,
35.7,
29.6,
28.4,
29,
27.8,
27.8,
27.8,
28.4,
27.8,
27.8,
27.8,
27.3,
27.3,
27.8,
28.4,
27.8,
27.8,
27.8,
27.8,
32,
27.8,
27.8,
27.8,
28.4,
29,
28.4,
28.4,
27.8,
28.4,
28.4,
28.4,
28.4,
28.4,
27.8,
27.3,
26.7,
25.7,
25.2,
25.2,
25.2,
25.7,
25.7,
25.7,
25.7,
25.7,
25.2,
25.2,
24.6,
25.2,
26.2,
25.7,
25.7,
25.2,
25.7,
24.6,
25.2,
25.2,
25.2,
25.2,
24.6,
24.6,
24.6,
24.6,
24.6,
24.6,
24.1,
24.1,
24.1,
23.6,
22.5,
22.5,
22,
22,
22,
22,
22,
22,
22.5,
24.6,
24.6,
25.7,
25.7,
24.1,
24.6,
26.2,
25.7,
32,
26.2,
26.7,
25.7,
25.2,
25.2,
25.7,
24.1,
24.1,
24.6,
27.3,
32,
32,
30.8,
29.6,
29.6,
29,
27.8,
26.7,
26.7,
26.2,
25.2,
25.2,
25.2,
24.6,
25.2,
23.6,
24.1,
24.1,
24.1,
24.1,
25.7,
30.8,
50.9,
62.6,
53.3,
43.2,
59.1,
85.8,
116,
121,
78.8,
57.4,
51.7,
47.7,
44,
40.2,
44,
60.9,
64.3,
69,
76,
69,
67.8,
78.8,
71.3,
64.3,
81.6,
141,
141,
90,
76,
69,
60.9,
59.1,
57.4,
57.4,
54.1,
52.5,
47,
43.2,
38.9,
35.1,
32.6,
33.8,
43.2,
52.5,
71.3,
73.7,
90,
96.4,
99.6,
116,
99.6,
94.8,
113,
76,
78.8,
81.6,
60.9,
47.7,
42.4,
40.2,
38.9,
42.4,
54.1,
57.4,
76,
72.5,
71.3,
71.3,
63.4,
57.4,
49.3,
46.2,
46.2,
50.1,
143,
134,
84.4,
76,
67.8,
62.6,
55.7,
51.7,
53.3,
62.6,
84.4,
113,
93.2,
78.8,
71.3,
59.1,
49.3,
44,
42.4,
47,
48.5,
44.7,
43.2,
40.2,
41,
49.3,
53.3,
65.5,
67.8,
59.1,
54.1,
52.5,
50.9,
50.9,
61.7,
66.6,
73.7,
66.6,
57.4,
52.5,
45.4,
44.7,
47.7,
50.9,
54.1,
56.6,
48.4,
43.2,
38.9,
37.6,
38.3,
38.3,
37.6,
40.2,
44.7,
55.7,
60.9,
59.1,
55.7,
54.9,
50.1,
53.3,
49.3,
46.2,
44.7,
43.2,
41,
41,
44,
41,
37,
33.8,
32.6,
32,
31.4,
30.2,
30.8,
32,
30.8,
33.8,
38.3,
44,
49.3,
49.3,
53.3,
49.3,
40.2,
35.7,
33.2,
32.6,
32,
31.4,
35.7,
33.8,
31.4,
30.8,
30.8,
27.8,
29,
29,
27.8,
29,
28.4,
28.4,
27.8,
27.8,
26.7,
27.3,
27.8,
27.8,
27.8,
27.8,
28.4,
28.4,
28.4,
27.8,
27.3,
27.8,
26.7,
26.7,
27.8,
28.4,
33.8,
41,
38.3,
29,
29,
29.6,
29,
28.4,
28.4,
27.3,
32,
29,
28.4,
27.8,
26.7,
24.6,
29.6,
37.6,
31.4,
29.6,
28.4,
29,
35.7,
54.1,
29,
29,
30.2,
28.4,
27.8,
28.4,
26.7,
27.3,
27.3,
26.7,
26.2,
26.2,
26.2,
26.2,
25.7,
24.6,
24.6,
26.2,
26.7,
26.7,
26.7,
26.2,
26.2,
25.7,
25.7,
24.6,
25.2,
25.7,
25.2,
25.7,
26.2,
25.2,
26.2,
25.2,
25.2,
25.2,
24.6,
24.6,
24.6,
24.6,
24.6,
24.6,
24.6,
24.6,
24.6,
24.6,
24.6,
24.6,
24.6,
24.6,
24.6,
24.6,
24.6,
24.6,
24.6,
25.70),
start=c(1972,1),frequency=365)				   
prec <- stats::ts(c(
8.1,
4.4,
7,
0,
0,
0,
1.9,
1.2,
0,
0.1,
0,
0.2,
1.8,
0.2,
0.2,
0.2,
1.5,
9.2,
1,
0.2,
0.4,
2.5,
3.3,
0.2,
0.1,
0,
0,
4.8,
19.4,
0.9,
0.1,
0,
0,
0,
0,
0.2,
0.1,
0.1,
0,
3.8,
0,
0.1,
0.1,
0.1,
0.2,
0,
0,
2.9,
2.1,
6.7,
11.2,
6.1,
2.1,
42.2,
12.5,
0.1,
0.3,
0.3,
0.2,
0,
1.2,
0.1,
0.5,
0,
0,
0,
1.7,
0.5,
1.8,
2.1,
16.1,
0.6,
0.2,
4,
4,
1.3,
22.4,
35.7,
8.7,
1.2,
0.3,
0.1,
1.1,
6.5,
7,
0.6,
0.2,
0.2,
0.1,
0,
0,
0,
3.3,
0.3,
0.1,
0.1,
0,
1.6,
0.3,
1.9,
0,
0,
0.3,
1.3,
0.1,
0,
1.7,
0.1,
0.1,
0.1,
0.2,
0,
0.1,
0.1,
0.2,
0.1,
0.1,
0.2,
3.7,
0.1,
0,
0,
0,
0,
1.8,
20.7,
0.1,
0.1,
0,
0,
0.1,
0,
0,
0,
0.2,
0.2,
5.6,
1.8,
7,
0.3,
0.1,
0.2,
0,
0,
0,
0,
0.1,
0.2,
0.8,
0,
0,
0.2,
0.2,
2.6,
3.8,
1.8,
0.1,
0.6,
0.4,
0,
0.5,
0,
0,
1.3,
0,
4.4,
1.2,
13.8,
0,
0.9,
0.3,
0.3,
0.6,
0.3,
2.4,
8.4,
6.3,
2.2,
4.4,
1.6,
7,
2.2,
1.7,
0.6,
13.6,
2.2,
1.1,
0.1,
2.6,
11.4,
0.7,
5.1,
0.1,
0.4,
3.2,
10.2,
4.2,
8.4,
0,
2.8,
0,
7.2,
2.5,
4.8,
0,
0,
0,
1.4,
2.9,
5.5,
0,
0,
0,
0,
0.2,
0,
0,
1.9,
1.3,
0.1,
0.1,
0,
0,
0,
0.4,
8,
10.8,
3.6,
0.1,
0.1,
0.1,
14.8,
5.4,
0.1,
5.3,
0.2,
0.3,
0.2,
5,
4.9,
2.1,
6,
3.9,
0.2,
7.5,
0.6,
0,
0.4,
1.8,
0.1,
0,
0,
0,
0,
0,
1.9,
1.7,
0.1,
0.4,
0,
1.2,
1.2,
1.3,
7,
0.2,
2.6,
0.9,
25,
0.6,
0,
3.3,
1,
5.4,
5.2,
0.2,
0.7,
11.3,
0,
6.2,
6.5,
0,
9.6,
0,
0.6,
3.7,
54,
3.4,
0.1,
1.5,
16.2,
0,
0.1,
0,
0,
4.3,
0.2,
0.3,
1,
0,
0.1,
0.1,
24.9,
3.5,
1.2,
2.9,
0,
2.2,
0.7,
3.7,
0.4,
3.8,
6.7,
0.2,
0,
0.8,
2.4,
0.5,
0.3,
0.2,
0.3,
0.2,
0,
1.1,
0.4,
0.2,
0.9,
0.2,
0,
9.9,
18,
14.3,
0.8,
4.1,
4.6,
1.9,
0,
1.3,
0,
0,
0,
0,
0.1,
0.1,
0,
0,
0.2,
0.1,
0,
0,
0.5,
0,
1.9,
2.3,
18.5,
10.8,
8.4,
4.2,
1.4,
0,
2.6,
11.7,
0.2,
0.8,
2.2,
9.1,
0.6,
2.8,
1.3,
0.6,
5.5,
1.3,
3.1,
15.2,
5.8,
4.1,
0.4,
0.1,
1.7,
2.4,
0.1,
0,
1.5,
0.9,
0.7,
9.2,
0.7,
0,
0.6,
1,
1.8,
0,
0,
0,
9.4,
0,
1.2,
0,
0,
8.2,
13.7,
10.7,
1.3,
6.6,
0,
1.5,
1,
0,
9,
0.8,
1.6,
1.9,
0.7,
0.8,
3.2,
10.9,
1.8,
2.8,
11.1,
0.1,
0,
0,
0,
0,
3,
6.7,
4.3,
0,
1.6,
1,
0.1,
0,
1.9,
20.7,
0.2,
0,
24.3,
5,
0.2,
0.1,
10.3,
2.6,
0,
0.1,
0,
0.1,
7.5,
6,
0.1,
1.2,
0,
3.9,
12.9,
0.1,
2.9,
2,
0,
0,
0,
0.1,
4.3,
0.1,
0.1,
0,
0,
0,
0,
0,
0,
0,
1,
0.8,
0.8,
1.1,
1.5,
0.1,
0.1,
1,
0.2,
0,
0,
0,
0,
0,
0.1,
0,
0.1,
0,
0,
0,
0,
0.1,
0,
0,
3,
0.1,
0.2,
0.2,
0.2,
0.2,
1.3,
0.8,
16.1,
16.3,
0.2,
0,
0,
0,
0,
0,
0,
0,
6.3,
0.1,
2.1,
2.4,
0.1,
0.2,
0,
0,
0.8,
0,
2.9,
0.1,
2.4,
0.7,
0.3,
0.5,
1.2,
0.2,
0,
0,
1.7,
14.4,
2.1,
4.3,
11.5,
0.2,
1.3,
2.6,
2.9,
0,
0.2,
9,
2.3,
1.6,
2.4,
0,
0.1,
1.6,
3.6,
3.6,
0.1,
12.4,
0.3,
0.2,
1.1,
0.1,
0,
0.3,
0.4,
8.9,
0.1,
0.4,
0.2,
0,
0,
0,
0,
0.1,
0,
0,
0,
0,
1.9,
0.2,
1.2,
0.1,
0,
0,
0,
11.1,
1.4,
1.4,
22,
2,
0,
0.8,
10.1,
4.7,
0,
13.6,
2.5,
2.7,
0.3,
0.4,
0,
0,
0,
0,
0,
0,
0,
3.4,
6.3,
0.4,
9.3,
4.3,
0.1,
0.9,
9.3,
0.2,
0.5,
0.5,
0.1,
0.7,
0.1,
0.2,
0.1,
0,
0,
0,
0.1,
3.9,
0.2,
0,
0.1,
1.7,
0.4,
0.2,
0.8,
0,
0,
5.7,
18,
12,
2,
0,
0.2,
0.1,
1.2,
3.8,
13,
0.1,
3.5,
0.2,
0.1,
6.4,
1,
0,
0,
0.2,
0,
0,
0,
0,
0.1,
0,
0,
0,
0,
4.3,
5.1,
7,
4.1,
17.7,
5.4,
0,
7.8,
20.8,
37.6,
1.1,
0.1,
1.2,
0.5,
0.2,
0,
11.4,
9.8,
2,
0.1,
0.1,
2.9,
0,
0,
0,
0,
0,
0.1,
0.3,
0.7,
2.2,
2.1,
0.1,
0,
0,
1.7,
0.3,
0,
0,
0,
0.1,
5.6,
1.2,
2.8,
6.1,
0.4,
0,
0.3,
4.5,
0.9,
0,
4.6,
0.8,
0,
2.5,
3.9,
0.4,
0,
0,
2.3,
0,
0,
0,
0,
3.6,
0.2,
4.9,
0.3,
1.9,
0.5,
0,
3,
0.3,
0,
2.2,
0.7,
2.9,
3.5,
0.7,
1.4,
4.6,
0.1,
1.6,
0.1,
0,
0,
1.6,
0.8,
2.5,
0,
30.8,
6.8,
1.9,
1.9,
0.4,
6.7,
1.6,
3.3,
3,
0.2,
0,
0.3,
0.1,
0,
0,
0,
0,
0,
0.1,
0.1,
0,
1.8,
0.6,
0.7,
0.2,
0,
0,
0,
0.5,
3.6,
2.3,
2.7,
1.9,
1.8,
1.5,
18,
1.8,
60.3,
17.3,
5.5,
4.6,
0.6,
0.9,
5.4,
2.9,
0.1,
2.6,
8.2,
24.1,
0.9,
0.2,
0.1,
0,
0,
0,
0,
0.8,
0,
0,
0,
0,
0,
4.3,
5.8,
3.4,
0.1,
0,
1.1,
12,
5.1,
77.7,
25.6,
3,
4,
10.8,
5.7,
10,
10.3,
10.5,
3.2,
0,
0.7,
0.4,
2,
0.9,
0.4,
0.5,
0,
0,
5.4,
0.4,
4,
0,
0.6,
0.6,
6.4,
6,
0.5,
0.1,
0,
0,
0.4,
6.1,
0,
0,
0,
0,
0,
0,
0,
0,
0,
1.1,
3.6,
0.1,
0.1,
9.6,
1,
0.1,
0.6,
0,
0,
0.6,
0.4,
0,
0,
0.4,
3.6,
0,
0,
0,
0.1,
0.6,
2,
3.9,
0.9,
2.9,
1.4,
0.1,
0,
0,
13.4,
2.9,
5.7,
79.3,
19.4,
7.2,
8.2,
4.9,
3.9,
3.8,
6.2,
0.1,
0,
0,
0,
0,
0,
0,
1.2,
0,
0,
0.1,
2.5,
5.4,
1.2,
0,
0.9,
0.1,
2,
5.7,
5.5,
13.4,
0,
0,
0,
0,
0,
0,
3.6,
0.2,
0.4,
0.2,
2.7,
0.2,
0,
0,
0,
1.4,
0,
0,
0,
2.1,
0.2,
0.5,
0.2,
0,
1,
0.6,
2.9,
10.2,
3,
2.1,
0,
0,
0.1,
0.1,
0.2,
0,
0,
0.1,
2.8,
1.5,
0.1,
0.1,
1.5,
3.5,
0.4,
0.7,
0.1,
0,
0.8,
1.3,
10.2,
1.7,
1.9,
0.9,
1.7,
5.4,
1.6,
0.1,
0.1,
0.1,
1.5,
0.3,
3.4,
10.5,
0.4,
3.9,
0.5,
1.5,
0.2,
0.1,
0.1,
0.1,
0,
0,
0,
0,
0.2,
0.2,
0,
0.1,
0,
2.4,
0,
0.1,
0.2,
0.3,
0,
0,
0,
0.1,
0,
0.2,
0.1,
6.3,
7.1,
16.1,
6.4,
4.9,
6.3,
0.1,
0.2,
0,
0,
15,
25.9,
0.2,
10.8,
1,
0,
3.5,
1.3,
1.9,
2,
0,
0.1,
0,
18.5,
7,
1.8,
4.5,
0.3,
0.7,
0.3,
0.4,
0.2,
1.3,
0.5,
0.2,
0.2,
0,
0,
0,
0,
0,
0,
0.8,
0.7,
0.2,
3.5,
0,
0,
1.6,
2.8,
1.1,
0.2,
1.2,
0.1,
4,
0.3,
3.7,
1.1,
0.2,
0.1,
1.5,
0.4,
1.8,
0.1,
0.3,
0.3,
0.1,
0.1,
0.4,
1.2,
0,
0,
0.4,
0.1,
0,
0,
7.1,
0.1,
0.3,
8.1),
start=c(1972,1),frequency=365)			   
temp <- stats::ts(c(
0.9,
1.6,
0.1,
0.6,
2,
0.8,
1.4,
1.3,
2.2,
0.1,
3,
-0.2,
-2.6,
-3.8,
0.9,
1.9,
-0.4,
-6,
-5,
-4.6,
-5.3,
-7.3,
-8.5,
-9.9,
-13.1,
-10.2,
-8.7,
0.4,
1.9,
0.8,
-1.6,
-0.9,
0.5,
-4.1,
-2.8,
-2.6,
-3.3,
-2.8,
-7.6,
-5.8,
-6.4,
-5.9,
-5.3,
-8.6,
-12.6,
-15.3,
-7.4,
0.5,
1.1,
-2.4,
-0.7,
-4.5,
-0.6,
0.3,
0.2,
0.7,
0.8,
2.3,
0.1,
1.1,
-1.4,
-0.6,
0.3,
-1.1,
-3.6,
-1.9,
0.1,
-0.4,
-3.9,
-1.2,
-4,
-4.8,
-7.8,
-3.1,
-4.6,
2.2,
1,
-1.6,
-3.2,
0.1,
-5.2,
-6.5,
-5.3,
0,
-6.8,
-6.9,
-5,
-9.4,
-9.4,
-10.4,
-8.4,
0.9,
-7,
-11.7,
-9,
-7.9,
-8.4,
-9.8,
-13.4,
-2.8,
-1.2,
-1.6,
-0.2,
-2.6,
-3.6,
-2.1,
0.1,
0.1,
0.5,
0.9,
1,
0.7,
2.4,
3,
2.7,
0,
-0.2,
-0.3,
-3.2,
-6.8,
-6.8,
-6.4,
-3.1,
-0.5,
0.8,
2.2,
3,
4.7,
4,
3.5,
4.4,
4.3,
4,
2.9,
1.8,
1.8,
1.6,
1.6,
1.8,
3.4,
4.5,
5.8,
3.3,
4.8,
4.1,
4.2,
1.6,
1.1,
1.6,
2.4,
2.5,
1.7,
2.2,
4.1,
3.1,
3.4,
5.5,
2.2,
3.3,
5.6,
6.3,
6.1,
6.2,
8.5,
5.5,
7,
4.7,
2.3,
1.3,
-0.2,
1.3,
2.9,
4.5,
5.9,
4.4,
2.2,
4.4,
4.4,
3.4,
5.2,
6.2,
6.5,
7,
6.1,
1.9,
3.5,
6.9,
6.2,
6.4,
6.5,
6.7,
6.7,
7.6,
6.1,
5.1,
3.6,
4.8,
7.5,
6.1,
6.8,
6.7,
7.9,
7,
5.8,
6,
6.1,
7.5,
7.8,
9.1,
7.1,
6.4,
6.8,
7.4,
6.7,
3.7,
4.7,
3.4,
1.4,
2.6,
2.5,
3.2,
5.8,
7.2,
6.2,
8.9,
7.2,
5.5,
4.4,
4.9,
4.7,
4.4,
3.5,
4.2,
5,
5.2,
5.5,
3.6,
3.4,
6.5,
6.4,
8.8,
6.1,
4.3,
4.5,
6.9,
4.8,
5.8,
6,
2.6,
-1.7,
-0.8,
-0.8,
0.1,
-0.1,
2,
2.6,
3.8,
7.3,
6.3,
4.6,
6.2,
4.2,
4.7,
4.3,
3.1,
3.8,
7.2,
4.6,
6.4,
6.1,
4.5,
4.2,
2.9,
1.1,
0.9,
2.1,
1,
0.6,
5.3,
1.7,
0.1,
-1.1,
-2.4,
-5.8,
1.7,
2.4,
0.6,
-1.4,
2.1,
-1.6,
-0.2,
2.6,
0.7,
2.3,
-1.3,
-2.5,
-4.9,
-4.4,
-4.7,
-5.4,
-4.4,
1.3,
1.4,
-1.3,
-1.7,
-2.9,
-2.8,
-2.9,
-2.3,
-3.1,
-0.5,
-4.3,
-7.1,
-7.5,
-4.7,
-5,
-6.4,
-8.5,
-10.4,
-15.2,
-10.6,
-9.3,
-8,
-7.9,
-7.8,
-8.9,
-14.2,
-3.6,
-0.1,
-2.4,
0.2,
-1.3,
-6.1,
-5.7,
-5,
-4.2,
-3.8,
-6.3,
-7,
-6.2,
-6.3,
-5.4,
-11,
-8.5,
-5.6,
-9.5,
-3.7,
-3.7,
-3.2,
-3.8,
1.3,
3.5,
2.5,
0.9,
-1.5,
-3.2,
-4.9,
-6.1,
-3.4,
1.4,
-6.2,
-5.2,
-7.4,
-3,
-4.1,
-6.5,
-4.9,
-6.8,
-1.7,
-0.7,
1.9,
2.4,
1.9,
1.7,
3.2,
3.3,
0.6,
0.6,
-1.9,
-1.4,
1.3,
-4.5,
-6.1,
0.1,
-4.2,
1.6,
-1.5,
-1.5,
-2.8,
-3.9,
-5.6,
-10.9,
-6.4,
-0.8,
-2.2,
-5.3,
-9.9,
-2.5,
-4.9,
-0.3,
-3.3,
-5.4,
-5.1,
-14.9,
-12.7,
-12.4,
-9.5,
-4.3,
-14.4,
-14.5,
-14.5,
-11.2,
-4.8,
-3.4,
-10.5,
-6.2,
-1.6,
-6.2,
-11.3,
-14.7,
-18.3,
-10.3,
-10.8,
-2.8,
-3.6,
-4.8,
-2.7,
-5.6,
-7.7,
-10.7,
-7,
-0.1,
-0.5,
-6,
-2.7,
1.3,
1.3,
1,
1,
0.4,
1.6,
-0.2,
2.2,
1.7,
0.6,
1.2,
-3.1,
-10.5,
-13.4,
-10.7,
-1.3,
-5.6,
-6.7,
-4.9,
-13.7,
-15.8,
-16.6,
-15.8,
-5,
-8,
-6.5,
-7,
-7.1,
-1.5,
2.2,
2.4,
3.2,
2.8,
0.9,
2.2,
-0.4,
-1.5,
1.3,
2.6,
2.3,
1.9,
1.5,
1.4,
1.9,
1.7,
0,
-1.6,
-8.2,
-7.3,
-7.8,
-5.1,
-5.7,
-6.5,
-3.3,
-0.8,
-0.4,
-0.1,
-0.2,
-3.1,
-3.9,
-3.7,
-3.4,
-4.8,
-3.8,
0.3,
1.7,
2.4,
1.9,
0,
2,
3.8,
2.9,
3.3,
2.6,
1.8,
2.7,
2.9,
1.5,
2,
-0.5,
-1.4,
-0.7,
-0.8,
-0.5,
2.4,
2.6,
2.4,
1.5,
1.2,
1.9,
0.2,
-1.5,
-2.8,
-1.7,
-0.9,
2.6,
3,
6.9,
6.5,
6,
3.9,
4.2,
6,
6.7,
5.6,
5.7,
4.5,
4.1,
4.1,
4.8,
5.2,
1.5,
1.7,
3.3,
4.5,
5.4,
3.4,
5.5,
4.1,
5.1,
6.5,
9.3,
10.5,
8.4,
9.3,
11.7,
10.2,
8.4,
9.8,
10.1,
7.5,
7.9,
9.7,
10.5,
11.5,
11,
10,
8.3,
6.4,
6.8,
5.4,
3.5,
6.7,
8.4,
6.4,
6.8,
5.8,
4.5,
3.4,
2.4,
4,
4.2,
5.2,
5.3,
6.3,
6.5,
6.1,
8.5,
6.7,
2,
1.8,
2.8,
3.8,
5.3,
7.9,
10.3,
10.3,
10.2,
8.6,
7.2,
7.5,
6.5,
7.1,
6,
4.8,
4.3,
3.8,
4.2,
5,
3.1,
3.8,
1.3,
1.5,
4.7,
7.5,
8.5,
8,
6.6,
7.3,
7.3,
8.7,
7.5,
5,
2.1,
2,
2.2,
4.2,
3.3,
2.4,
1.2,
0,
-1.2,
-0.3,
2.9,
6.3,
6.9,
3.9,
1.7,
4.6,
6.1,
4.2,
0.1,
-4.2,
-3.9,
-0.9,
-3.5,
-1.4,
-5,
-7,
-7.3,
-10.2,
-8.3,
-3.1,
-4.6,
-1.7,
1.5,
0.2,
0.8,
-0.1,
-0.6,
-3.1,
-2.8,
2.3,
4.3,
-0.2,
-0.2,
-1.3,
-3.9,
-7.7,
-11.5,
-2.7,
1.3,
-0.8,
-4.8,
-9.1,
-5.6,
-4.1,
-9.1,
-10.4,
-15.8,
-15.8,
-15.3,
-13.4,
-11.6,
-2.2,
-2.4,
-10.8,
-17.4,
-18.3,
-16.3,
-8.9,
-4.6,
-6.7,
-5.6,
-3.8,
0.1,
0.1,
-2.5,
-2.8,
-5.7,
-15.5,
-16.3,
-5.4,
-4.2,
-11.2,
-11.2,
-8.4,
-18.8,
-14.7,
-6.2,
-12.4,
-22.4,
-21.4,
-14,
-13,
-15.8,
-15.2,
-16.6,
-7.1,
-4.8,
-5.3,
-8.8,
-8,
-12.3,
-13.3,
-10.7,
-9.4,
-8.4,
-3.3,
-0.1,
-0.4,
0.1,
-1.3,
-3.2,
-2.7,
-4.1,
-2,
-3.5,
-3.3,
-3.9,
-6.1,
-7.9,
-4.8,
-8.2,
-2.1,
-1.9,
-4.3,
-0.6,
-2,
-3.4,
-6.2,
-4.7,
-5.2,
-8.1,
-3.6,
-5.6,
-2.4,
-4.3,
-3.4,
-1.7,
-4.6,
-9.4,
-12.7,
-14.7,
-14.3,
-14.2,
-9.2,
-9.4,
-4.7,
-8.5,
-10.9,
-15.2,
-12.8,
-1.5,
-4.1,
-3.5,
-0.7,
-3.4,
-11.6,
-1.3,
-1.9,
-0.4,
-0.7,
-3,
-0.4,
-5.4,
-9.8,
-1.5,
1,
0.5,
0.1,
-0.7,
1.2,
2.5,
1.3,
0.6,
0.2,
-0.8,
-3,
-4.3,
-4.7,
-4.1,
-2.9,
-5.9,
-6.7,
-2.3,
1.4,
-0.1,
0.4,
-0.7,
-3.4,
-1.8,
-0.5,
1.6,
1,
1.6,
0.2,
-1.9,
-1.9,
2,
2.1,
2.1,
0.9,
-0.4,
-1.3,
-1.4,
-0.5,
-0.8,
0.8,
2.3,
2.1,
2,
2.1,
1.8,
2.5,
2.5,
0.9,
0.8,
2.5,
2.7,
2.7,
1.7,
0.4,
0.3,
1.9,
3.2,
3.8,
3.5,
1.3,
2.5,
1.9,
1.4,
0.3,
0,
0.1,
2.7,
5.5,
4.2,
4.9,
5.1,
5.2,
6.1,
5.7,
5.3,
4.4,
5.6,
5,
2.7,
4.6,
5.2,
4.7,
2,
-0.9,
0.6,
1.6,
2.4,
5.5,
6.2,
7.5,
4.9,
3.8,
5.9,
4.4,
3.9,
1.2,
2,
3.1,
4,
6.9,
6.8,
3.4,
4.2,
3.3,
3,
2,
3,
5.9,
8.8,
13.1,
13.9,
12.4,
12,
10.1,
6.3,
3,
3.1,
4.2,
3.9,
5.1,
6.3,
6.3,
3,
7.4,
7.7,
9.8,
10.3,
9.5,
8.2,
4,
6.9,
8.3,
8.5,
6.9,
8.5,
8.1,
7.7,
6.5,
5.6,
3.7,
7.9,
9.7,
10.9,
9.7,
11.5,
9,
3.5,
4,
3.3,
6.1,
5.7,
5.9,
7.2,
8.9,
8.9,
10.1,
9.4,
9.2,
10.7,
9.3,
10,
7.4,
6.6,
5.5,
6,
6.8,
6.3,
6.3,
5.4,
3.1,
1.6,
2.9,
1.5,
0.6,
-0.4,
1.2,
2.1,
5,
5.8,
8.4,
6.3,
9,
7.8,
5.9,
5.6,
3.6,
1.9,
1.6,
2.2,
3.6,
3.5,
5.2,
3.3,
0.9,
0.7,
0.8,
-2.8,
-1.6,
-1.2,
1.4,
-1.1,
-3.9,
-5.6,
-4.6,
-3.4,
-3.2,
-5,
-4.7,
-3,
-0.8,
-0.2,
0.1,
0.3,
0.3,
-2.7,
-2.3,
-2,
-1,
-0.6,
0.9,
2.1,
2.5,
5.3,
4.2,
2,
0.1,
1.4,
-1.4,
-3.1,
-1.2,
-1.2,
-1.2,
2.7,
-4.3,
-1.6,
-1.1,
-8.4,
-10.6,
0.6,
0.7,
-1.3,
-1.1,
-0.6,
-0.1,
2,
0.5,
-1.3,
0.3,
-0.4,
-4.8,
-5.8,
-2.6,
-5.8,
-4.2,
-4.6,
-4,
-6.1,
-8.6,
-8.7,
-4.6,
-5.8,
-4.6,
-2.6,
-2,
-1.8,
-2.8,
-3.2,
-5.9,
-7,
-1.8,
-2.6,
-3.5,
-4.2,
-4.7,
-11.6,
-5.9,
-1.8,
-5.3,
-3.4,
-10.5,
-12.7,
-13.2,
-14.2,
-3.8,
-9.1,
-11.1,
-7.2,
-9.1,
-12.7,
-13.2,
-12.7,
-17,
-19.4,
-11.6,
-7.3,
-9.8,
-11.3,
-4.1,
-5.9,
-6.8,
-2.4,
-5.4),
start=c(1972,1),frequency=365)
ice.river <- stats::ts.union (flow.vat, flow.jok, prec,temp)
